<?php


class TeknisaWebserver {

    private $invalidDirectories = [
        '.',
        '..',
        'AssistantLogs',
        'AssistantTools'
    ];

    private $invalidDirectoriesParts = [
        'log', '.php', 'apache', 'apache74', 'packages'
    ];

    public function run() {
        $outputJSON = [
            "name"          => "Teknisa Local Webserver",
            "description"   => "",
            "phpVersion"    => phpversion(),
            "products"      => []
        ];

        $dir     = __DIR__."/..";
        $folders = array_diff(scandir($dir), $this->invalidDirectories);

        $tmpInvalidDirectories = [];

        foreach($folders as $folder) {

            if(!is_dir($dir . DIRECTORY_SEPARATOR . $folder)) {
                array_push($tmpInvalidDirectories, $folder);
                continue;
            }

            foreach($this->invalidDirectoriesParts as $part) {
                if(strpos(strtolower($folder), strtolower($part)) || (strtolower($folder) == strtolower($part))) {
                    array_push($tmpInvalidDirectories, $folder);
                }
            }
        }

        $folders = array_diff($folders, $tmpInvalidDirectories);

        $i = 0;
        foreach($folders as $folder) {

            $currentFolder   = $dir . DIRECTORY_SEPARATOR . $folder;
            $versionsFolders = array_diff(scandir($currentFolder), $this->invalidDirectories);

            $outputJSON['products'][$i]['name'] = $folder;
            $outputJSON['products'][$i]['versions'] = [];

            foreach($versionsFolders as $versionFolder) {
                $versionFolderFull = $dir . DIRECTORY_SEPARATOR . $folder . DIRECTORY_SEPARATOR . $versionFolder;

                if($versionFolder == 'main' || preg_match("/[0-9]{1,3}.[0-9]{1,3}.[0-9]{1,3}/i", $versionFolder)) {

                    $productInfoFile = $dir . DIRECTORY_SEPARATOR . $folder . DIRECTORY_SEPARATOR . $versionFolder . DIRECTORY_SEPARATOR . 'productInfo.json';
                    if(file_exists($productInfoFile)) {
                        $productInfoData = file_get_contents($productInfoFile);
                        $productInfoData = json_decode($productInfoData, true);

                        array_push($outputJSON['products'][$i]['versions'], [
                            "path"   => "/$folder/$versionFolder",
                            "info"   => $productInfoData
                        ]);
    
                    }
                }
            }

            $i++;
        }

        $outputJSON['products'] = array_filter($outputJSON['products'], function($arr) {
            return !empty($arr['versions']);
        });

        $outputJSON['products'] = array_values($outputJSON['products']);

        echo json_encode($outputJSON, JSON_PRETTY_PRINT);
    }
}

$app = new TeknisaWebserver();
$app->run();